/*
 *      uart.h
 *
 *      Copyright 2008 Ronny Schmiedel <http://avrs-at-leipzig.de>
 *
 *		Original from Peter Fleury <http://homepage.hispeed.ch/peterfleury/>
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 *
 *      AVR306: Using the AVR UART in C using IRQ
 *      Port for AVR GCC/WinAVR
 *      Routines for interrupt controlled USART
 *      Supports ATMEGA8, ATMEGA16
 *      Last Edit: 02.01.2009
 */
 
#ifndef UART_H
#define UART_H
 
/* UART Buffer Defines */
#define UART_RX_BUFFER_SIZE 32     /* 2,4,8,16,32,64,128 or 256 bytes */
#define UART_TX_BUFFER_SIZE 32     /* 2,4,8,16,32,64,128 or 256 bytes */
#define UART_RX_BUFFER_MASK ( UART_RX_BUFFER_SIZE - 1 )
#define UART_TX_BUFFER_MASK ( UART_TX_BUFFER_SIZE - 1 )
#if ( UART_RX_BUFFER_SIZE & UART_RX_BUFFER_MASK )
	#error RX buffer size is not a power of 2
#endif
#if ( UART_TX_BUFFER_SIZE & UART_TX_BUFFER_MASK )
	#error TX buffer size is not a power of 2
#endif
 
 
#define F_CPU				8000000
#define UART_BAUD_RATE		9600
 
/* Prototypes */
/**
 * @brief	Initialize USART
 * @return	void
 */
extern void uart_init (void);
 
/**
 * @brief	Receives Char from USART Buffer
 * @param	void
 * @return	char
 */
extern unsigned char uart_getc( void );
 
/**
 * @brief	Sends Char to USART Buffer
 * @param	Char to send
 * @void
 */
extern void uart_putc( unsigned char data );
 
/**
 * @brief	Sends String to USART Buffer
 * @param	Char to send
 * @void
 */
extern void uart_puts(const char *s );
 
/**
 * @brief	Test if received char is in Buffer
 * @param	void
 * @return	Return 0 (FALSE) if the receive buffer is empty
 */
extern char uart_data_received( void );
 
#endif